@@ -2,6 +2,8 @@
 #
 
 edit.nb <- function(name, coords, polys=NULL, ..., use_region.id=FALSE) {
+  if (.Platform$GUI == "RStudio")
+    stop("do not use in RStudio, use an R console session")
   nb <- name
   cnb <- card(nb)
 # class to inherits Jari Oksanen 080603
@@ -25,7 +27,7 @@ edit.nb <- function(name, coords, polys=NULL, ..., use_region.id=FALSE) {
   plot.window(xlim = xlim, ylim = ylim, "", asp=1)
   if (!is.null(polys))
     if (inherits(polys, "SpatialPolygons"))
-        plot(polys, border="grey", add=TRUE)
+        sp::plot(polys, border="grey", add=TRUE)
     else stop("polys of unknown class")
 # bug report Conceicao Ribeiro 100731
   for (i in 1:n) {
@@ -39,6 +41,7 @@ edit.nb <- function(name, coords, polys=NULL, ..., use_region.id=FALSE) {
   }
   points(x, y)
   finished <- "n"
+  if (!interactive()) finished <- "q"
   deletions <- NULL
   additions <- NULL
 ###
@@ -132,7 +135,7 @@ edit.nb <- function(name, coords, polys=NULL, ..., use_region.id=FALSE) {
       plot.new()
       plot.window(xlim = xlim, ylim = ylim, "", asp=1)
       if (!is.null(polys))
-         plot(polys, border="grey", add=TRUE)
+         sp::plot(polys, border="grey", add=TRUE)
       for (i in 1:n) {
         if(nb[[i]][1]!=0 & length(nb[[i]])>0L)
           segments(x[i],y[i],x[nb[[i]]],y[nb[[i]]])
@@ -159,6 +162,12 @@ edit.nb <- function(name, coords, polys=NULL, ..., use_region.id=FALSE) {
   if (is.null(icl)) class(nb) <- "nb"
   else class(nb) <- c("nb", icl)
   nb <- sym.attr.nb(nb)
+  NE <- n + sum(card(nb))
+  if (get.SubgraphOption() && get.SubgraphCeiling() > NE) {
+    ncomp <- n.comp.nb(nb)
+    attr(z, "ncomp") <- ncomp
+    if (ncomp$nc > 1) warning("neighbour object has ", ncomp$nc, " sub-graphs")
+  }
   nb
 }
 
