@@ -41,12 +41,14 @@ geary.test <- function(x, listw, randomisation=TRUE,
         if (is.null(zero.policy))
             zero.policy <- get.ZeroPolicyOption()
         stopifnot(is.logical(zero.policy))
+	stopifnot(length(zero.policy) == 1L)
 	alternative <- match.arg(alternative, c("less", "greater", "two.sided"))
 	wname <- deparse(substitute(listw))
 	if (!inherits(listw, "listw")) stop(wname, "is not a listw object")
         xname <- deparse(substitute(x))
 	if(!is.numeric(x)) stop(xname,
 		" is not a numeric vector")
+	stopifnot(length(na.action) == 1L)
 	if (deparse(substitute(na.action)) == "na.pass")
 	    stop("na.pass not permitted")
 	x <- na.action(x)
@@ -58,6 +60,8 @@ geary.test <- function(x, listw, randomisation=TRUE,
 	n <- length(listw$neighbours)
 	if (n != length(x)) stop("objects of different length")
 	if (is.null(spChk)) spChk <- get.spChkOption()
+        stopifnot(is.logical(spChk))
+	stopifnot(length(spChk) == 1L)
 	if (spChk && !chkIDs(x, listw))
 		stop("Check of data and weights ID integrity failed")
 	
@@ -117,6 +121,7 @@ geary.mc <- function(x, listw, nsim, zero.policy=attr(listw, "zero.policy"),
         if (is.null(zero.policy))
             zero.policy <- get.ZeroPolicyOption()
         stopifnot(is.logical(zero.policy))
+	stopifnot(length(zero.policy) == 1L)
         stopifnot(is.vector(x))
 	alternative <- match.arg(alternative, c("less", "greater", "two.sided"))
 	wname <- deparse(substitute(listw))
@@ -124,6 +129,7 @@ geary.mc <- function(x, listw, nsim, zero.policy=attr(listw, "zero.policy"),
         xname <- deparse(substitute(x))
 	if(!is.numeric(x)) stop(xname, " is not a numeric vector")
 	if(missing(nsim)) stop("nsim must be given")
+	stopifnot(length(na.action) == 1L)
 	if (deparse(substitute(na.action)) == "na.pass")
 	    stop("na.pass not permitted")
 	x <- na.action(x)
@@ -137,6 +143,8 @@ geary.mc <- function(x, listw, nsim, zero.policy=attr(listw, "zero.policy"),
 	n <- length(listw$neighbours)
 	if (n != length(x)) stop("objects of different length")
 	if (is.null(spChk)) spChk <- get.spChkOption()
+        stopifnot(is.logical(spChk))
+	stopifnot(length(spChk) == 1L)
 	if (spChk && !chkIDs(x, listw))
 		stop("Check of data and weights ID integrity failed")
         gamres <- suppressWarnings(nsim > gamma(n + 1))
