@@ -3,7 +3,7 @@
 
 
 knn2nb <- function(knn, row.names=NULL, sym=FALSE) {
-	if (class(knn) != "knn") stop("Not a knn object")
+	if (!inherits(knn, "knn")) stop("Not a knn object")
 	res <- vector(mode="list", length=knn$np)
     	if (!is.null(row.names)) {
 		if(length(row.names) != knn$np)
@@ -27,5 +27,11 @@ knn2nb <- function(knn, row.names=NULL, sym=FALSE) {
 	attr(res, "type") <- "knn"
  	attr(res, "knn-k") <- knn$k
 	class(res) <- "nb"
-	invisible(res)
+        NE <- length(res) + sum(card(res))
+        if (get.SubgraphOption() && get.SubgraphCeiling() > NE) {
+          ncomp <- n.comp.nb(res)
+          attr(res, "ncomp") <- ncomp
+          if (ncomp$nc > 1) warning("neighbour object has ", ncomp$nc, " sub-graphs")
+        }
+	res
 }
