@@ -30,10 +30,14 @@ moran.test <- function(x, listw, randomisation=TRUE, zero.policy=attr(listw, "ze
         if (is.null(zero.policy))
             zero.policy <- get.ZeroPolicyOption()
         stopifnot(is.logical(zero.policy))
+	stopifnot(length(zero.policy) == 1L)
 	if (is.null(spChk)) spChk <- get.spChkOption()
+        stopifnot(is.logical(spChk))
+	stopifnot(length(spChk) == 1L)
 	if (spChk && !chkIDs(x, listw))
 		stop("Check of data and weights ID integrity failed")
 #	if (any(is.na(x))) stop("NA in X")
+	stopifnot(length(na.action) == 1L)
 	NAOK <- deparse(substitute(na.action)) == "na.pass"
 	x <- na.action(x)
 	na.act <- attr(x, "na.action")
@@ -104,14 +108,18 @@ moran.mc <- function(x, listw, nsim, zero.policy=attr(listw, "zero.policy"),
         if (is.null(zero.policy))
             zero.policy <- get.ZeroPolicyOption()
         stopifnot(is.logical(zero.policy))
+	stopifnot(length(zero.policy) == 1L)
 	if(missing(nsim)) stop("nsim must be given")
 	if (is.null(spChk)) spChk <- get.spChkOption()
+        stopifnot(is.logical(spChk))
+	stopifnot(length(spChk) == 1L)
 	if (spChk && !chkIDs(x, listw))
 		stop("Check of data and weights ID integrity failed")
 	cards <- card(listw$neighbours)
 	if (!zero.policy && any(cards == 0))
 		stop("regions with no neighbours found")
 #	if (any(is.na(x))) stop("NA in X")
+	stopifnot(length(na.action) == 1L)
 	if (deparse(substitute(na.action)) == "na.pass")
 	    stop("na.pass not permitted")
 	x <- na.action(x)
