@@ -1,7 +1,7 @@
-# Copyright 2001-15 by Roger Bivand 
+# Copyright 2001-15 by Roger Bivand
 #
 
-spweights.constants <- function(listw, zero.policy=NULL, adjust.n=TRUE) {
+spweights.constants <- function(listw, zero.policy=attr(listw, "zero.policy"), adjust.n=TRUE) {
     if (get.listw_is_CsparseMatrix_Option()) {
         stopifnot(is(listw, "CsparseMatrix"))
         cards <- rowSums(listw > 0)
@@ -19,7 +19,7 @@ spweights.constants <- function(listw, zero.policy=NULL, adjust.n=TRUE) {
 		"is not a listw object"))
 	cards <- card(listw$neighbours)
         if (is.null(zero.policy))
-            zero.policy <- get("zeroPolicy", envir = .spdepOptions)
+            zero.policy <- get.ZeroPolicyOption()
         stopifnot(is.logical(zero.policy))
 	if (!zero.policy && any(cards == 0))
 		stop("regions with no neighbours found")
@@ -65,7 +65,7 @@ Szero <- function(listw) {
 	sum(unlist(listw$weights))
 }
 
-lag.listw <- function(x, var, zero.policy=NULL, NAOK=FALSE, ...) {
+lag.listw <- function(x, var, zero.policy=attr(listw, "zero.policy"), NAOK=FALSE, ...) {
     if (!is.logical(NAOK)) stop("NAOK must be logical")
     if (get.listw_is_CsparseMatrix_Option()) {
 	if (!NAOK && any(is.na(var))) stop("NA in variable")
@@ -74,7 +74,7 @@ lag.listw <- function(x, var, zero.policy=NULL, NAOK=FALSE, ...) {
     } else {
 	listw <- x
         if (is.null(zero.policy))
-            zero.policy <- get("zeroPolicy", envir = .spdepOptions)
+            zero.policy <- get.ZeroPolicyOption()
         stopifnot(is.logical(zero.policy))
 	if (!inherits(listw, "listw")) stop(paste(deparse(substitute(x)),
 		"is not a listw object"))
@@ -105,7 +105,7 @@ lag.listw <- function(x, var, zero.policy=NULL, NAOK=FALSE, ...) {
 				naok=NAOK, PACKAGE="spdep")
 
 		}
-	} 
+	}
     }
     if (any(is.na(res))) warning("NAs in lagged values")
     res
@@ -154,10 +154,10 @@ listw2U <- function(listw) {
 			    iwt <- wts[[i]]
 			    vlist[[i]] <- numeric(length=length(inl))
 			    for (j in 1:length(inl)) {
-				if (inl[j] %in% inb) 
+				if (inl[j] %in% inb)
 				    a <- iwt[which(inb == inl[j])]
 				else a <- 0
-				if (i %in% nb[[inl[j]]]) 
+				if (i %in% nb[[inl[j]]])
 				    b <- wts[[inl[j]]][which(nb[[inl[j]]] == i)]
 				else b <- 0
 				vlist[[i]][j] <- 0.5 * (a + b)
@@ -175,9 +175,9 @@ listw2U <- function(listw) {
 }
 
 
-listw2star <- function(listw, ireg, style, n, D, a, zero.policy=NULL) {
+listw2star <- function(listw, ireg, style, n, D, a, zero.policy=attr(listw, "zero.policy")) {
         if (is.null(zero.policy))
-            zero.policy <- get("zeroPolicy", envir = .spdepOptions)
+            zero.policy <- get.ZeroPolicyOption()
         stopifnot(is.logical(zero.policy))
     nb <- vector(mode="list", length=n)
     class(nb) <- "nb"
@@ -199,6 +199,7 @@ listw2star <- function(listw, ireg, style, n, D, a, zero.policy=NULL) {
             nb[[jj]] <- ireg
             wts[[jj]] <- iwts[j]
 	}
+        attributes(wts) <- attributes(listw$weights)
     }
     res <- list(style=style, neighbours=nb, weights=wts)
     class(res) <- c("listw", "star")
@@ -209,9 +210,16 @@ listw2star <- function(listw, ireg, style, n, D, a, zero.policy=NULL) {
 spdep <- function(build=FALSE) {
 #	require("utils")
 	.DESC <- packageDescription("spdep")
-	.spdep.Version <- paste(.DESC[["Package"]], ", version ", 
+	.spdep.Version <- paste(.DESC[["Package"]], ", version ",
 		.DESC[["Version"]], ", ", .DESC[["Date"]], sep="")
 	.spdep.Build <- paste("build:", .DESC[["Built"]])
 	if (build) return(c(.spdep.Version, .spdep.Build))
 	else return(.spdep.Version)
 }
+
+
+
+# find neighbor values
+find_xj <- function(x, nb) {
+  lapply(nb, FUN = function(nbs_i) x[nbs_i])
+}
